==> vala-0.5.7.tar.gz: vala-0.5.7/vala/valafield.h <==
/* valafield.vala
 *
 * Copyright (C) 2006-2009  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAFIELD_H__
#define __VALA_VALAFIELD_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <vala/valamember.h>
#include <vala/valalockable.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_FIELD (vala_field_get_type ())
#define VALA_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FIELD, ValaField))
#define VALA_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FIELD, ValaFieldClass))
#define VALA_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FIELD))
#define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
#define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))

typedef struct _ValaFieldPrivate ValaFieldPrivate;

/**
 * Represents a type or namespace field.
 */
struct _ValaField {
	ValaMember parent_instance;
	ValaFieldPrivate * priv;
};

struct _ValaFieldClass {
	ValaMemberClass parent_class;
};


ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
char* vala_field_get_cname (ValaField* self);
void vala_field_set_cname (ValaField* self, const char* cname);
char* vala_field_get_default_cname (ValaField* self);
char* vala_field_get_array_length_cname (ValaField* self);
void vala_field_set_array_length_cname (ValaField* self, const char* array_length_cname);
char* vala_field_get_array_length_cexpr (ValaField* self);
void vala_field_set_array_length_cexpr (ValaField* self, const char* array_length_cexpr);
void vala_field_process_attributes (ValaField* self);
char* vala_field_get_ctype (ValaField* self);
void vala_field_set_ctype (ValaField* self, const char* ctype);
ValaDataType* vala_field_get_field_type (ValaField* self);
void vala_field_set_field_type (ValaField* self, ValaDataType* value);
ValaExpression* vala_field_get_initializer (ValaField* self);
void vala_field_set_initializer (ValaField* self, ValaExpression* value);
MemberBinding vala_field_get_binding (ValaField* self);
void vala_field_set_binding (ValaField* self, MemberBinding value);
gboolean vala_field_get_is_volatile (ValaField* self);
void vala_field_set_is_volatile (ValaField* self, gboolean value);
gboolean vala_field_get_no_array_length (ValaField* self);
void vala_field_set_no_array_length (ValaField* self, gboolean value);
gboolean vala_field_get_array_null_terminated (ValaField* self);
void vala_field_set_array_null_terminated (ValaField* self, gboolean value);
gboolean vala_field_get_has_array_length_cname (ValaField* self);
gboolean vala_field_get_has_array_length_cexpr (ValaField* self);
GType vala_field_get_type (void);


G_END_DECLS

#endif

==> vala-0.6.1.tar.gz: vala-0.6.1/vala/valafield.h <==
/* valafield.vala
 *
 * Copyright (C) 2006-2009  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#ifndef __VALA_VALAFIELD_H__
#define __VALA_VALAFIELD_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <vala/valamember.h>
#include <vala/valalockable.h>
#include <vala/valacodenode.h>

G_BEGIN_DECLS


#define VALA_TYPE_FIELD (vala_field_get_type ())
#define VALA_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_FIELD, ValaField))
#define VALA_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_FIELD, ValaFieldClass))
#define VALA_IS_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_FIELD))
#define VALA_IS_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_FIELD))
#define VALA_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_FIELD, ValaFieldClass))

typedef struct _ValaFieldPrivate ValaFieldPrivate;

/**
 * Represents a type or namespace field.
 */
struct _ValaField {
	ValaMember parent_instance;
	ValaFieldPrivate * priv;
};

struct _ValaFieldClass {
	ValaMemberClass parent_class;
};


ValaField* vala_field_construct (GType object_type, const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
ValaField* vala_field_new (const char* name, ValaDataType* field_type, ValaExpression* initializer, ValaSourceReference* source_reference);
char* vala_field_get_cname (ValaField* self);
void vala_field_set_cname (ValaField* self, const char* cname);
char* vala_field_get_default_cname (ValaField* self);
char* vala_field_get_array_length_cname (ValaField* self);
void vala_field_set_array_length_cname (ValaField* self, const char* array_length_cname);
char* vala_field_get_array_length_cexpr (ValaField* self);
void vala_field_set_array_length_cexpr (ValaField* self, const char* array_length_cexpr);
void vala_field_process_attributes (ValaField* self);
char* vala_field_get_ctype (ValaField* self);
void vala_field_set_ctype (ValaField* self, const char* ctype);
ValaDataType* vala_field_get_field_type (ValaField* self);
void vala_field_set_field_type (ValaField* self, ValaDataType* value);
ValaExpression* vala_field_get_initializer (ValaField* self);
void vala_field_set_initializer (ValaField* self, ValaExpression* value);
MemberBinding vala_field_get_binding (ValaField* self);
void vala_field_set_binding (ValaField* self, MemberBinding value);
gboolean vala_field_get_is_volatile (ValaField* self);
void vala_field_set_is_volatile (ValaField* self, gboolean value);
gboolean vala_field_get_no_array_length (ValaField* self);
void vala_field_set_no_array_length (ValaField* self, gboolean value);
gboolean vala_field_get_no_delegate_target (ValaField* self);
void vala_field_set_no_delegate_target (ValaField* self, gboolean value);
gboolean vala_field_get_array_null_terminated (ValaField* self);
void vala_field_set_array_null_terminated (ValaField* self, gboolean value);
gboolean vala_field_get_has_array_length_cname (ValaField* self);
gboolean vala_field_get_has_array_length_cexpr (ValaField* self);
GType vala_field_get_type (void);


G_END_DECLS

#endif
